{% extends "layout.html" %}
{% block content %}
<h1>Video Recording</h1>
{% if data['video_recording_list']|count %}
    <ul>
    {% for video_recording in data['video_recording_list'] %}
        <li><a href="{{ url_for('testbatch.video_player', video_path = video_recording['path'], video_title = video_recording['title']) }}">{{ video_recording['title'] }}</a></li>
    {% endfor %}
    </ul>
{% else %}
    <div class="text-center">
        <h1>There is no video recording!</h1>
    </div>
{% endif %}
{% endblock %}
