videojs.addLanguage("nl",{
 "Play": "Afspelen",
 "Pause": "Pauze",
 "Current Time": "Huidige Tijd",
 "Duration Time": "Looptijd",
 "Remaining Time": "Resterende Tijd",
 "Stream Type": "Stream Type",
 "LIVE": "LIVE",
 "Loaded": "Geladen",
 "Progress": "Status",
 "Fullscreen": "Volledig scherm",
 "Non-Fullscreen": "Geen volledig scherm",
 "Mute": "Geluid Uit",
 "Unmuted": "Geluid Aan",
 "Playback Rate": "Weergave Rate",
 "Subtitles": "Ondertiteling",
 "subtitles off": "Ondertiteling uit",
 "Captions": "Onderschriften",
 "captions off": "Onderschriften uit",
 "Chapters": "Hoofdstukken",
 "You aborted the media playback": "Je hebt de media weergave afgebroken.",
 "A network error caused the media download to fail part-way.": "De media download is mislukt door een netwerkfout.",
 "The media could not be loaded, either because the server or network failed or because the format is not supported.": "De media kon niet worden geladen, veroorzaakt door een server of netwerkfout of het formaat word niet ondersteund.",
 "The media playback was aborted due to a corruption problem or because the media used features your browser did not support.": "De media weergave is afgebroken omdat deze beschadigd is of de media gebruikt functionaliteit die niet door je browser word ondersteund.",
 "No compatible source was found for this media.": "Voor deze media is geen ondersteunde bron gevonden."
});