{% extends "layout.html" %}
{% block content %}
<script type="text/javascript">
    $(function() {
        $('#accordion').puiaccordion({multiple:true});
    });
</script>
{% if data['test_instance_list']|count %}
    <div id="accordion">
    {% for test_instance in data['test_instance_list'] %}
            <h3>{{ test_instance.name }}</h3>
            <div>
                <p><b>Public ip:</b> {{ test_instance.public_ip }}</p>
                <p><b>Public dns:</b> {{ test_instance.public_dns }}</p>
                <p><b>Private ip:</b> {{ test_instance.private_ip }}</p>
                <p><b>Private dns:</b> {{ test_instance.private_dns }}</p>
                <p><b>{{ test_instance.running_info }}</b></p>
            </div>
    {% endfor %}
    </div>
{% else %}
    <div class="text-center">
        <h1>There is no test instance alive!</h1>
    </div>
{% endif %}
{% endblock %}
