/*
 * Copyright 2009-2012 Prime Teknoloji.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
.pui-shadow{-moz-box-shadow:0 5px 10px rgba(0,0,0,0.8);-webkit-box-shadow:0 5px 10px rgba(0,0,0,0.8);box-shadow:0 5px 10px rgba(0,0,0,0.8);}
.pui-fluid *{box-sizing:border-box;-webkit-box-sizing:border-box;-moz-box-sizing:border-box;}
.ui-widget .ui-icon.fa,.ui-icon.fa{background:none repeat scroll 0 0 transparent!important;text-indent:0!important;}.pui-accordion{width:100%;}
.pui-accordion .pui-accordion-header{cursor:pointer;position:relative;margin-top:1px;zoom:1;}
.pui-accordion .pui-accordion-header a{display:block;font-size:1em;padding:.5em .5em .5em 2.2em;}
.pui-accordion .pui-accordion-header .pui-icon{position:absolute;left:.5em;top:50%;margin-top:-8px;}
.pui-accordion .pui-accordion-content{padding:1em 2.2em;border-top:0;margin-top:-2px;position:relative;top:1px;margin-bottom:2px;overflow:auto;zoom:1;}
.pui-accordion .pui-accordion-header.ui-state-disabled,.pui-accordion .pui-accordion-header.ui-state-disabled a{cursor:default;}.pui-autocomplete{width:auto;zoom:1;cursor:pointer;-moz-box-shadow:none;-webkit-box-shadow:none;box-shadow:none;position:relative;display:inline-block;}
.pui-autocomplete .pui-autocomplete-dropdown{position:absolute;top:0;bottom:0;height:100%;width:2.4em;right:-2.4em;}
.pui-autocomplete-query{font-weight:bold;}
.pui-autocomplete-panel{position:absolute;overflow:auto;}
.pui-autocomplete-panel .pui-autocomplete-list{padding:.4em;border:0 none;}
.pui-autocomplete-panel .pui-autocomplete-list-item{border:0 none;cursor:pointer;font-weight:normal;margin:1px 0;padding:3px 5px;text-align:left;}
.pui-autocomplete-panel .pui-autocomplete-table{border-collapse:collapse;width:100%;}
.pui-autocomplete-panel .pui-autocomplete-table td{border-width:1px;border-style:solid;border-color:inherit;padding:4px 10px 4px 10px;}
.pui-autocomplete .ui-button-icon-only .ui-button-text{padding:.29em;}
.pui-autocomplete-multiple{clear:left;cursor:text;list-style-type:none;margin:0;min-height:1px;overflow:hidden;width:400px;padding:0;}
.pui-autocomplete-token{cursor:default;float:left;overflow:hidden;padding:1px 3px;white-space:nowrap;position:relative;margin:2px;}
.pui-autocomplete-token-label{display:block;padding:0 2.1em 0 .5em;}
.pui-autocomplete-token-icon{margin-top:-9px;position:absolute;right:.2em;top:50%;cursor:pointer;}
.pui-autocomplete-input-token{float:left;list-style-type:none;margin:1px;padding:0;}
.pui-autocomplete-input-token .pui-inputtext{border:0 none;width:140px;outline:medium none;background-color:transparent;margin:0;padding:4px;box-shadow:none;}.pui-button{display:inline-block;position:relative;padding:0;margin-right:.1em;text-decoration:none!important;cursor:pointer;text-align:center;zoom:1;overflow:visible;}
.pui-button-icon-only{width:2.4em;}
.pui-button .pui-button-text{display:block;line-height:normal;}
.pui-button-text-only .pui-button-text{padding:.3em 1em;}
.pui-button-icon-only .pui-button-text{padding:.3em;text-indent:-9999999px;}
.pui-button-text-icon-left .pui-button-text{padding:.3em 1em .3em 2.1em;}
.pui-button-text-icon-right .pui-button-text{padding:.3em 2.1em .3em 1em;}
.pui-button-icon-only .pui-icon,.pui-button-text-icon-left .pui-icon,.pui-button-text-icon-right .pui-icon{position:absolute;top:50%;margin-top:-7px;}
.pui-button-icon-only .pui-icon{left:50%;margin-left:-8px;}
.pui-button-icon-left{left:.5em;}
.pui-button-icon-right{right:.5em;}
.pui-buttonset{margin-right:7px;}
.pui-buttonset .pui-button{margin-left:0;margin-right:0;}
button.pui-button::-moz-focus-inner{border:0;padding:0;}
.pui-fluid .pui-button{width:100%;}
.pui-fluid .ui-buttonset{width:100%;}.pui-chkbox{display:inline-block;cursor:pointer;}
.pui-chkbox .pui-chkbox-box{float:left;width:16px;height:16px;-moz-border-radius:2px;-webkit-border-radius:2px;border-radius:2px;margin-right:3px;}
.pui-chkbox .pui-chkbox-icon{margin-top:1px;margin-left:-1px;}
.pui-chkbox .pui-chkbox-label{cursor:pointer;display:block;margin:0 3px;outline:medium none;z-index:1;float:left;}.pui-datatable table{border-collapse:collapse;width:100%;table-layout:fixed;}
.pui-datatable .pui-datatable-header,.pui-datatable .pui-datatable-footer{text-align:center;padding:4px 10px;}
.pui-datatable .pui-datatable-caption{border-bottom:0 none;text-align:center;padding:4px 10px;}
.pui-datatable .pui-datatable-footer{border-top:0 none;}
.pui-datatable thead th,.pui-datatable tfoot td{text-align:center;}
.pui-datatable thead th,.pui-datatable tbody td,.pui-datatable tfoot td{padding:4px 10px;overflow:hidden;white-space:nowrap;border-width:1px;border-style:solid;}
.pui-datatable tbody td{border-color:inherit;}
.pui-datatable .pui-sortable-column{cursor:pointer;}
.pui-datatable .pui-sortable-column-icon{display:inline-block;margin:-3px 0 -3px 2px;}
.pui-datatable .pui-paginator{border-top:0 none;}
.pui-datatable .pui-datatable-data tr.ui-state-hover{font-weight:inherit;cursor:pointer;}
.pui-datatable tr.ui-state-highlight{cursor:pointer;}
.pui-datatable-scrollable-header,.pui-datatable-scrollable-footer{border:0 none;overflow:hidden;}
.pui-datatable-scrollable-body{overflow:auto;}
.pui-datatable-reflow .pui-datatable-data td .pui-column-title{display:none;}
@media(max-width:35em){.pui-datatable-reflow thead th,.pui-datatable-reflow tfoot td{display:none;}
.pui-datatable-reflow .pui-datatable-data td{text-align:left;display:block;border:0 none;width:100%;-webkit-box-sizing:border-box;-moz-box-sizing:border-box;box-sizing:border-box;float:left;clear:left;}
.pui-datatable-reflow .pui-datatable-data.ui-widget-content{border:0 none;}
.pui-datatable-reflow .pui-datatable-data tr.ui-widget-content{border-left:0 none;border-right:0 none;}
.pui-datatable-reflow .pui-datatable-data td .pui-column-title{padding:.4em;min-width:30%;display:inline-block;margin:-.4em 1em -.4em -.4em;}
}.pui-dialog{position:fixed;padding:0;overflow:hidden;}
.pui-dialog .pui-dialog-titlebar{padding:.4em .4em .4em 1em;position:relative;border:0;}
.pui-dialog .pui-dialog-title{float:left;margin:.3em 16px .1em 0;}
.pui-dialog .pui-dialog-content{position:relative;border:0;padding:.5em 1em;background:none;overflow:auto;zoom:1;}
.pui-dialog .pui-dialog-buttonpane{text-align:left;border-width:1px 0 0 0;background-image:none;margin:.5em 0 0 0;padding:.3em 1em .5em .4em;}
.pui-dialog .pui-dialog-buttonpane .pui-dialog-buttonset{float:right;}
.pui-dialog .pui-dialog-buttonpane button{margin:.5em .4em .5em 0;cursor:pointer;}
.pui-dialog .ui-resizable-se{width:14px;height:14px;right:3px;bottom:3px;}
.ui-draggable .pui-dialog-titlebar{cursor:move;}
.pui-dialog .pui-dialog-titlebar-close,.pui-dialog .pui-dialog-titlebar-minimize,.pui-dialog .pui-dialog-titlebar-maximize{float:right;margin-top:2px;top:0;padding:1px;cursor:pointer;height:16px;}
.pui-dialog .pui-dialog-titlebar-close span,.pui-dialog .pui-dialog-titlebar-minimize span,.pui-dialog .pui-dialog-titlebar-maximize span{display:block;margin:0;}
.pui-dialog .pui-dialog-titlebar-close:hover,.pui-dialog .pui-dialog-titlebar-close:focus,.pui-dialog .pui-dialog-titlebar-minimize:hover,.pui-dialog .pui-dialog-titlebar-minimize:focus,.pui-dialog .pui-dialog-titlebar-maximize:hover,.pui-dialog .pui-dialog-titlebar-maximize:focus{padding:0;}
.pui-dialog-footer{padding:.4em 1em;border-width:1px 0 0 0;text-align:left;}
.pui-dialog-docking-zone{position:fixed;bottom:0;left:0;}
.pui-dialog-minimizing{border:2px dotted gray;}
.ui-confirm-dialog-severity{float:left;margin:3px 7px 20px 0;}
.pui-dialog.pui-dialog-minimized{*width:200px!important;}
.pui-dialog-rtl{direction:rtl;}
.pui-dialog.pui-dialog-rtl .pui-dialog-title{float:right;}
.pui-dialog.pui-dialog-rtl .pui-dialog-titlebar-close,.pui-dialog.pui-dialog-rtl .pui-dialog-titlebar-minimize,.pui-dialog.pui-dialog-rtl .pui-dialog-titlebar-maximize{float:left;}
.pui-dialog.pui-dialog-rtl .pui-dialog-footer{text-align:right;}.pui-dropdown{display:inline-block;position:relative;width:auto;zoom:1;cursor:pointer;padding-right:2em;}
.pui-dropdown .pui-dropdown-trigger{border-right:none;border-top:none;border-bottom:none;cursor:pointer;width:16px;height:100%;position:absolute;right:0;top:0;padding:0 3px;}
.pui-dropdown .pui-dropdown-trigger .pui-icon{margin-top:4px;margin-left:-1px;}
.pui-dropdown .pui-dropdown-label{display:block;border:none;white-space:nowrap;overflow:hidden;font-weight:normal;width:100%;float:left;}
.pui-dropdown.ui-state-disabled .pui-dropdown-trigger,.pui-dropdown.ui-state-disabled .pui-dropdown-label{cursor:default;}
.pui-dropdown label.pui-dropdown-label{cursor:pointer;}
.pui-dropdown input.pui-dropdown-label{cursor:default;}
.pui-dropdown-panel{position:absolute;height:auto;}
.pui-dropdown-panel .pui-dropdown-items-wrapper{overflow:auto;}
.pui-dropdown-panel .pui-dropdown-item{font-weight:normal;}
.pui-dropdown-panel .pui-dropdown-item-group{font-weight:bold;}
.pui-dropdown-panel .pui-dropdown-list{padding:.4em;border:0 none;}
.pui-dropdown-panel .pui-dropdown-list-item{border:0 none;cursor:pointer;margin:1px 0;padding:3px 5px;text-align:left;}
.pui-dropdown-panel .pui-dropdown-filter{width:85%;padding-right:18px;}
.pui-dropdown-panel .pui-dropdown-filter-container{position:relative;margin:0;padding:.4em;display:inline-block;}
.pui-dropdown-panel .pui-dropdown-filter-container .pui-icon{position:absolute;top:10px;right:15px;}
.pui-fluid .pui-dropdown{width:100%;}
.pui-fluid .pui-dropdown .pui-dropdown-trigger{width:32px;padding:0 6px;}.pui-fieldset,.pui-fieldset .pui-fieldset-legend{padding:.6em 1em;}
.pui-fieldset-toggleable .pui-fieldset-legend{padding:.5em 1em .5em .5em;cursor:pointer;white-space:nowrap;}
.pui-fieldset .pui-fieldset-toggler{padding-right:.1em;margin-top:.1em;float:left;}.pui-galleria{overflow:hidden;visibility:hidden;position:relative;}
.pui-galleria-panel-wrapper{position:relative;padding:0;margin:0;}
.pui-galleria-panel{filter:inherit;position:absolute;top:0;left:0;list-style-type:none;}
.pui-galleria-filmstrip-wrapper{overflow:hidden;margin:5px auto;position:relative;}
.pui-galleria-filmstrip{list-style:none outside none;margin:0;padding:0;width:2340px;z-index:900;position:absolute;top:0;left:0;}
.pui-galleria-frame{float:left;margin-right:5px;opacity:.3;cursor:pointer;}
.pui-galleria-frame-active{opacity:1;}
.pui-galleria-frame-content{overflow:hidden;}
.pui-galleria-nav-next,.pui-galleria-nav-prev{cursor:pointer;position:absolute;}
.pui-galleria-nav-prev{left:5px;}
.pui-galleria-nav-next{right:5px;}
.pui-galleria-caption{position:absolute;left:1px;background-color:rgba(0,0,0,0.5);display:none;color:#FFF;padding:.2em 1em;}
.pui-galleria-panel-content{padding:1em 1.4em;}* html .pui-growl{position:absolute;}
* html .pui-growl-item{padding-bottom:0;}
* html .pui-growl-icon-close{top:7px;right:7px;}
.pui-growl{position:fixed;top:20px;right:20px;width:301px;}
.pui-growl-item-container{position:relative;margin:0 0 10px 0;opacity:.85;filter:alpha(opacity=85);}
.pui-growl-item{display:block;padding:10px 15px;}
.pui-growl-item p{padding:0;margin:0;}
.pui-growl-icon-close{position:absolute;top:5px;right:3px;cursor:pointer;}
.pui-growl-title{font-weight:bold;padding:0 0 7px 0;display:block;}
.pui-growl-image{float:left;margin-left:5px;padding:0;display:block;}
.pui-growl-message{padding:0 0 5px 0;width:220px;float:right;}
.pui-growl-message p{font-weight:normal;}.pui-grid{clear:both;padding:0;margin:0;}
.pui-grid:before,.pui-grid:after{content:"";display:table;}
.pui-grid:after{clear:both;}
.pui-grid .pui-grid-row{display:-webkit-box;display:-moz-box;display:-ms-flexbox;display:-webkit-flex;display:flex;clear:both;}
.pui-grid-row:after{clear:both;content:"";display:table;}
.pui-grid-col-1,.pui-grid-col-2,.pui-grid-col-3,.pui-grid-col-4,.pui-grid-col-5,.pui-grid-col-6,.pui-grid-col-7,.pui-grid-col-8,.pui-grid-col-9,.pui-grid-col-10,.pui-grid-col-11,.pui-grid-col-12{float:left;box-sizing:border-box;}
.pui-grid-col-1{width:8.33333%;}
.pui-grid-col-2{width:16.66666%;}
.pui-grid-col-3{width:25%;}
.pui-grid-col-4{width:33.33333%;}
.pui-grid-col-5{width:41.66666%;}
.pui-grid-col-6{width:50%;}
.pui-grid-col-7{width:58.33333%;}
.pui-grid-col-8{width:66.66666%;}
.pui-grid-col-9{width:75%;}
.pui-grid-col-10{width:83.33333%;}
.pui-grid-col-11{width:91.66666%;}
.pui-grid-col-12{width:100%;}
@media(min-width:480px){.pui-grid-fixed{width:480px;}
}
@media(min-width:768px){.pui-grid-fixed{width:768px;}
}
@media(min-width:960px){.pui-grid-fixed{width:960px;}
}
@media(min-width:1024px){.pui-grid-fixed{width:1024px;}
}
@media(max-width:35em){.pui-grid-responsive .pui-grid-row{display:block;}
.pui-grid-responsive .pui-grid-col-1,.pui-grid-responsive .pui-grid-col-2,.pui-grid-responsive .pui-grid-col-3,.pui-grid-responsive .pui-grid-col-4,.pui-grid-responsive .pui-grid-col-5,.pui-grid-responsive .pui-grid-col-6,.pui-grid-responsive .pui-grid-col-7,.pui-grid-responsive .pui-grid-col-8,.pui-grid-responsive .pui-grid-col-9,.pui-grid-responsive .pui-grid-col-10,.pui-grid-responsive .pui-grid-col-11,.pui-grid-responsive .pui-grid-col-12{width:100%;float:none;}
}.pui-inputtext{margin:0;outline:medium none;padding:4px;font-weight:normal;}
.ui-widget-header .pui-inputtext,.ui-widget-content .pui-inputtext{font-weight:normal;}
.pui-fluid .pui-inputtext{width:100%;}.pui-inputtextarea-resizable{overflow:hidden;resize:none;}
.pui-fluid .pui-inputtextarea{width:100%;}.pui-lightbox{position:fixed;}
.pui-lightbox-content-wrapper{position:relative;}
.pui-lightbox-content{position:relative;margin:0;padding:0;background-color:#000;}
.pui-lightbox-nav-right,.pui-lightbox-nav-left{position:absolute;top:50%;cursor:pointer;}
.pui-lightbox-nav-left{left:0;}
.pui-lightbox-nav-right{right:0;}
.pui-lightbox-loading{background:url("loading.gif") #000 center center no-repeat;}
.pui-lightbox-caption{padding:.2em .4em;display:none;}
.pui-lightbox-caption-text{margin:.3em 0 .1em 0;float:left;}
.pui-lightbox-close{float:right;margin:0;padding:1px;}
.pui-lightbox-close.ui-state-hover{padding:0;}.pui-listbox{overflow:auto;padding:2px;width:125px;}
.pui-listbox .pui-listbox-list{list-style-type:none;margin:0;padding:0;}
.pui-listbox .pui-listbox-item{margin:2px;border:0 none;cursor:pointer;font-weight:normal;}.pui-menu{width:12.5em;padding:.3em;position:relative;}
.pui-menu.pui-menu-dynamic{position:absolute;display:none;z-index:100000;}
.pui-menu-list{position:static;}
.pui-menu .pui-menu-list .pui-menuitem{border:none;}
.pui-menu .pui-menu-list .ui-widget-header{clear:both;float:left;width:98%;margin:1px 0;}
.pui-menu .pui-menuitem{width:100%;float:left;clear:both;margin:1px 0;padding:0;}
.pui-menu .pui-menuitem-parent{width:100%;float:left;clear:both;margin:1px 0;padding:0;}
.pui-menu .pui-menuitem-link{display:block;width:92%;outline:none;text-decoration:none;font-weight:400;border:solid 1px transparent;float:left;line-height:16px;padding:.3em;cursor:pointer;}
.pui-menu .pui-menuitem-link .pui-menuitem-icon{display:inline-block;float:left;}
.pui-menu .pui-menuitem-text{float:left;}
.pui-menu .ui-widget-header h1,.pui-menu .ui-widget-header h2,.pui-menu .ui-widget-header h3,.pui-menu .ui-widget-header h4,.pui-menu .ui-widget-header h5,.pui-menu .ui-widget-header h6{float:left;display:block;font-size:1em;margin:0 auto;padding:.3em 3%;}
.pui-menu .pui-menu-parent .pui-menu-child{display:none;width:12.5em;padding:.3em;position:absolute;margin:0;outline:0;line-height:1.3;text-decoration:none;font-size:100%;list-style:none;}
.pui-menu .pui-menu-parent{position:relative;}
.pui-menu .pui-menu-parent .pui-submenu-icon{float:right;}
.pui-menubutton{padding:0;}
.pui-menubutton .ui-button{margin:0;}
.pui-menubar{width:auto;}
.pui-menubar .pui-menuitem{width:auto;clear:none;}
.pui-menubar .pui-menu-child .pui-menuitem{width:100%;}
.pui-menubar .pui-menu-child{top:25px;left:0;}
.pui-menubar .pui-menuitem-link{width:auto;padding:.4em .3em;}
.pui-menubar .pui-menu-child .pui-menuitem-link{width:92%;}
.pui-menubar .ui-widget-header{clear:none;width:auto;margin:0 3px 0 0;}
.pui-menubar .ui-widget-header h1,.pui-menubar .ui-widget-header h2,.pui-menubar .ui-widget-header h3,.pui-menubar .ui-widget-header h4,.pui-menubar .ui-widget-header h5,.pui-menubar .ui-widget-header h6{padding:.4em .3em;}
.pui-menubar .pui-menubar-options{float:right;}
.pui-menu .ui-separator{width:98%;height:0;float:left;clear:both;margin:1px 0 0 0;padding:0;border-top:0 none;}
.ui-megamenu td{vertical-align:top;}
.pui-menu.ui-megamenu .pui-menu-parent .pui-menu-child{width:auto;}
.pui-menu.ui-megamenu .pui-menu-child>table{width:auto;}
.pui-menu.ui-megamenu .pui-menu-child .pui-menu-list{width:12.5em;}
.pui-breadcrumb{margin:0;padding:0;overflow:hidden;padding:5px 5px 7px 5px;}
.pui-breadcrumb ul{margin:0;padding:0;display:block;}
.pui-breadcrumb ul li{display:block;float:left;position:relative;overflow:hidden;}
.pui-breadcrumb ul li span{display:block;overflow:hidden;}
.pui-breadcrumb ul li .pui-menuitem-link{display:block;position:relative;overflow:hidden;float:left;margin-top:3px;}
.pui-breadcrumb ul li.fa{padding:0;margin:4px 3px 0 3px;}
.pui-breadcrumb-chevron{float:left;}
.pui-slidemenu .pui-slidemenu-wrapper{position:relative;}
.pui-slidemenu .pui-slidemenu-content{overflow-x:hidden;overflow-y:auto;position:relative;}
.pui-slidemenu .pui-menu-list{position:absolute;top:0;}
.pui-slidemenu .pui-menu-parent{position:static;}
.pui-slidemenu .pui-menu-child{box-shadow:none;border:0 none;background:none repeat scroll 0 0 transparent;}
.pui-slidemenu-backward{position:absolute;bottom:0;width:95%;margin-bottom:.4em;padding:.2em;cursor:pointer;display:none;}
.pui-slidemenu-backward .pui-icon{float:left;margin-top:1px;}
.pui-fluid .pui-menu{width:100%;}.pui-messages{border:1px solid;margin:10px 0;padding:20px 20px 20px 10px;display:none;position:relative;}
.pui-messages-icon{display:block;float:left;margin-top:-5px;padding:0;position:relative;}
.pui-messages-summary{margin-left:10px;font-weight:bold;}
.pui-messages-detail{margin-left:5px;}
.pui-messages-info{color:#fff;background-color:#2196f3;border-color:#2196f3;}
.pui-messages-warn{color:#fff;background-color:#ff9800;border-color:#ff9800;}
.pui-messages-error{color:#fff;background-color:#f44336;border-color:#f44336;}
.pui-messages ul{margin:0 25px;padding:0;list-style-type:none;}
.pui-messages.pui-messages-noicon ul{margin:0 25px 0 0;}
.pui-messages .pui-messages-close{color:#fff;cursor:pointer;position:absolute;top:5px;right:5px;}.pui-notify{position:fixed;width:100%;height:100px;display:none;padding:10px;}
.pui-notify-top{top:0;}
.pui-notify-bottom{bottom:0;}
.pui-notify-close{position:absolute;right:3em;top:1em;cursor:pointer;opacity:.5;}
.pui-notify-close:hover{opacity:1.0;}.pui-paginator{margin:0;text-align:center;padding:2px;}
.pui-paginator .pui-paginator-top{border-bottom:0 none;}
.pui-paginator .pui-paginator-bottom{border-top:0 none;}
.pui-paginator .pui-paginator-page,.pui-paginator .pui-paginator-pages,.pui-paginator .pui-paginator-next,.pui-paginator .pui-paginator-last,.pui-paginator .pui-paginator-first,.pui-paginator .pui-paginator-prev,.pui-paginator .pui-paginator-current{display:inline-block;padding:2px 6px;zoom:1;margin-left:1px;margin-right:1px;text-decoration:none;outline:none;}
.pui-paginator .pui-paginator-page,.pui-paginator .pui-paginator-next,.pui-paginator .pui-paginator-last,.pui-paginator .pui-paginator-first,.pui-paginator .pui-paginator-prev{cursor:pointer;}
.pui-paginator .pui-paginator-current,.pui-paginator .pui-paginator-rpp-options{margin-left:1em;margin-right:1em;background-image:none;}
.pui-paginator .pui-paginator-next .ui-icon,.pui-paginator .pui-paginator-prev .ui-icon,.pui-paginator .pui-paginator-first .ui-icon,.pui-paginator .pui-paginator-last .ui-icon{height:auto;overflow:inherit;}
.pui-paginator .pui-paginator-jtp-select option,.pui-paginator .pui-paginator-rpp-options option{background-image:none;border:0 none;box-shadow:none;-moz-box-shadow:none;-webkit-box-shadow:none;}.pui-panel{padding:.2em;}
.pui-panel .pui-panel-titlebar{padding:.5em 1em .3em;}
.pui-panel .pui-panel-title{margin:.1em 16px .2em 0;}
.pui-panel .pui-panel-titlebar-icon{float:right;cursor:pointer;}
.pui-panel .pui-panel-titlebar-icon,.pui-panel .pui-panel-titlebar-icon:hover,.pui-panel .pui-panel-titlebar-icon:focus{margin-left:.2em;margin-top:-0.1em;*margin:-1.5em 0 0 .2em;}
.pui-panel .pui-panel-content{border:0;background:none;padding:.5em 1em;}
.pui-panel .pui-panel-footer{border-width:1px 0 0;margin:.5em 0 0;padding:.5em 1em;text-align:left;}
.pui-panel-collapsed-h .pui-panel-titlebar-icon,.pui-panel-collapsed-h .pui-panel-titlebar-icon:hover,.pui-panel-collapsed-h .pui-panel-titlebar-icon:focus{*margin:-0.2em 0 0 .1em;}
.pui-panel.pui-panel-collapsed-h{width:42px;}
.pui-panel.pui-panel-collapsed-h .pui-panel-title{display:none;}.pui-password-panel{padding:4px 10px;width:150px;margin-top:2px;}
.pui-password-panel .pui-password-meter{height:10px;background:transparent url("password-meter.png") no-repeat left top;padding:0;margin:0;}
.pui-password-info{margin-top:4px;}
.pui-password-panel-overlay{position:absolute;}.pui-picklist .pui-picklist-listwrapper{float:left;width:150px;}
.pui-picklist .pui-picklist-list{list-style-type:none;margin:0;padding:0;overflow:auto;height:200px;}
.pui-picklist .pui-picklist-buttons{float:left;margin:48px 10px 0 10px;padding:0;}
.pui-picklist .pui-picklist-list li{margin:1px;padding:2px;}
.pui-picklist .pui-button{display:block;margin-bottom:.3em;}
.pui-picklist .pui-picklist-item{cursor:pointer;border:0 none;font-weight:inherit;}
.pui-picklist .pui-picklist-caption{text-align:center;padding:4px 10px 4px 10px;border-bottom:0 none;}
.pui-picklist table{width:100%;border-collapse:collapse;}
.pui-picklist .pui-picklist-filter{padding-right:15px;width:86%;}
.pui-picklist .pui-picklist-filter-container{position:relative;margin:0;padding:0;}
.pui-picklist .pui-picklist-filter-container .pui-icon{position:absolute;top:5px;right:2px;}.pui-progressbar{height:1.2em;text-align:left;position:relative;}
.pui-progressbar .pui-progressbar-value{margin:-1px;height:100%;width:0;position:absolute;display:none;}
.pui-progressbar .pui-progressbar-label{text-align:center;height:100%;width:100%;position:absolute;display:none;font-weight:bold;}.pui-radiobutton{position:relative;width:16px;margin:2px 0;line-height:16px;cursor:pointer;}
.pui-radiobutton .pui-radiobutton-box{width:16px;height:16px;line-height:16px;-moz-border-radius:10px;-webkit-border-radius:10px;border-radius:10px;}
.pui-radiobutton-icon{font-size:10px;margin-top:3px;margin-left:2px;display:block;}.pui-rating-star,.pui-rating-cancel{float:left;display:block;overflow:hidden;text-indent:-999em;cursor:pointer;}
.pui-rating-star a,.pui-rating-cancel a{width:16px;height:15px;display:block;background:url("./images/rating.png") no-repeat 0 0;}
.pui-rating-star a{background-position:0 -32px;}
.pui-rating-star-on a{background-position:0 -48px;}
.pui-rating-star-hover a{background-position:0 -64px;}
.pui-rating-cancel-hover a{background-position:0 -16px;}
.pui-rating.ui-state-disabled .pui-rating-star,.pui-rating.ui-state-disabled .pui-rating-cancel{cursor:default;}.pui-spinner{display:inline-block;overflow:visible;padding:0;position:relative;vertical-align:middle;}
.pui-spinner-input{vertical-align:middle;text-align:right;padding-right:20px;}
.pui-spinner-button{cursor:default;display:block;font-size:.5em;height:50%;margin:0;overflow:hidden;padding:0;position:absolute;right:0;text-align:center;vertical-align:middle;width:16px;z-index:100;}
.pui-spinner .pui-icon{left:0;margin-top:-8px;position:absolute;top:50%;}
.pui-spinner-up{top:0;}
.pui-spinner-down{bottom:0;}.pui-fluid .pui-splitbutton .pui-button{width:96%;}
.pui-fluid .pui-splitbutton .pui-button.pui-splitbutton-menubutton{width:4%;}
@media(max-width:35em){.pui-fluid .pui-splitbutton .pui-button{width:90%;}
.pui-fluid .pui-splitbutton .pui-button.pui-splitbutton-menubutton{width:10%;}
}.pui-tabview{position:relative;padding:.2em;zoom:1;}
.pui-tabview .pui-tabview-nav{margin:0;}
.pui-tabview .pui-tabview-nav li{list-style:none;float:left;position:relative;margin:0 .2em 1px 0;padding:0;white-space:nowrap;}
.pui-tabview .pui-tabview-nav li a{float:left;padding:.5em 1em;text-decoration:none;}
.pui-tabview .pui-tabview-nav li.pui-tabview-selected a,.pui-tabview .pui-tabview-nav li.ui-state-disabled a,.pui-tabview .pui-tabview-nav li.ui-state-processing a{cursor:text;}
.pui-tabview .pui-tabview-nav li a,.pui-tabview.pui-tabview-collapsible .pui-tabview-nav li.pui-tabview-selected a{cursor:pointer;}
.pui-tabview .pui-tabview-panel{border-width:0;padding:1em 1.4em;background:none;}
.pui-tabview .pui-tabview-nav li{display:block;}
.pui-tabview .pui-tabview-nav li .fa{float:left;margin:.6em .3em 0 0;cursor:pointer;}
.pui-tabview.pui-tabview-top>.pui-tabview-nav li{border-bottom:0;top:1px;}
.pui-tabview.pui-tabview-top>.pui-tabview-nav{padding:.2em .2em 0;}
.pui-tabview.pui-tabview-bottom>.pui-tabview-nav{padding:0 .2em .2em;}
.pui-tabview.pui-tabview-bottom>.pui-tabview-nav li{border-top:0;}
.pui-tabview-left:after,.pui-tabview-right:after{clear:both;content:".";display:block;height:0;visibility:hidden;}
.pui-tabview-left>.pui-tabview-nav{float:left;width:23%;height:300px;background-image:none;padding-top:1px;}
.pui-tabview-left>.pui-tabview-panels{float:right;width:75%;}
.pui-tabview.pui-tabview-left>.pui-tabview-nav li,.pui-tabview.pui-tabview-right>.pui-tabview-nav li{display:block;float:right;white-space:normal;width:98%;}
.pui-tabview.pui-tabview-left>.pui-tabview-nav li{margin:0 0 1px .2em;border-right:0 none;}
.pui-tabview.pui-tabview-right>.pui-tabview-nav{float:right;width:23%;height:300px;background-image:none;padding-top:1px;}
.pui-tabview.pui-tabview-right>.pui-tabview-panels{float:left;width:75%;}
.pui-tabview.pui-tabview-right>.pui-tabview-nav li{margin:0 .2em 1px 0;border-left:0 none;}.pui-terminal{height:300px;overflow:auto;padding:3px;}
.pui-terminal-input{border:0 none;background-color:transparent;color:inherit;padding:0;margin:0 0 0 2px;width:75%;outline:none;vertical-align:baseline;}
.pui-terminal-command{margin-left:2px;-moz-margin-start:3px;}
.pui-terminal-input::-ms-clear{display:none;}.pui-tooltip{position:absolute;display:none;padding:3px 5px;}.pui-tree{width:300px;}
.pui-tree .pui-tree-container{height:100%;margin:0;overflow:auto;padding:3px;white-space:nowrap;}
.pui-tree .pui-treenode-children{margin:0;padding:0 0 0 16px;}
.pui-tree .pui-treenode{background-attachment:scroll;background-color:transparent;background-image:none;background-position:0 0;background-repeat:repeat-y;list-style:none outside none;margin:0;padding:1px 0 0;}
.pui-tree .pui-tree-toggler{cursor:pointer;display:inline-block;vertical-align:bottom;}
.pui-tree .pui-treenode-icon{display:inline-block;margin-top:3px;}
.pui-tree .pui-treenode-label{display:inline-block;margin:2px 0 0 0;vertical-align:top;padding:0 3px;}
.pui-tree .pui-treenode-selectable .pui-treenode-label,.pui-tree .pui-treenode-selectable .pui-treenode-icon{cursor:pointer;}
.pui-tree .pui-treenode-label.ui-state-hover,.pui-tree .pui-treenode-label.ui-state-highlight{font-weight:normal;border:0 none;}
.pui-tree .pui-treenode-leaf-icon{width:16px;height:16px;display:inline-block;}
.pui-tree .ui-chkbox-box{cursor:pointer;width:15px;height:15px;float:left;}
.pui-tree .ui-chkbox{display:inline-block;zoom:1;}.pui-treetable table{border-collapse:collapse;width:100%;table-layout:fixed;}
.pui-treetable .pui-treetable-header,.pui-treetable .pui-treetable-footer{text-align:center;padding:4px 10px;}
.pui-treetable .pui-treetable-header{border-bottom:0 none;}
.pui-treetable .pui-treetable-footer{border-top:0 none;}
.pui-treetable th,.pui-treetable tfoot td{text-align:center;}
.pui-treetable thead th,.pui-treetable tbody td,.pui-treetable tfoot td{padding:4px 10px;overflow:hidden;white-space:nowrap;border-width:1px;border-style:solid;}
.pui-treetable tbody td{border-color:inherit;}
.pui-treetable .pui-treetable-toggler{float:left;cursor:pointer;}
.pui-treetable .pui-treetable-data tr.ui-state-highlight,.pui-treetable .pui-treetable-data tr.ui-state-hover{cursor:pointer;}
.pui-treetable .pui-treetable-data tr.ui-state-hover{border-color:inherit;font-weight:inherit;}
.pui-treetable .pui-treetable-indent{width:16px;height:16px;float:left;}