.pui-datatable table{border-collapse:collapse;width:100%;table-layout:fixed;}
.pui-datatable .pui-datatable-header,.pui-datatable .pui-datatable-footer{text-align:center;padding:4px 10px;}
.pui-datatable .pui-datatable-caption{border-bottom:0 none;text-align:center;padding:4px 10px;}
.pui-datatable .pui-datatable-footer{border-top:0 none;}
.pui-datatable thead th,.pui-datatable tfoot td{text-align:center;}
.pui-datatable thead th,.pui-datatable tbody td,.pui-datatable tfoot td{padding:4px 10px;overflow:hidden;white-space:nowrap;border-width:1px;border-style:solid;}
.pui-datatable tbody td{border-color:inherit;}
.pui-datatable .pui-sortable-column{cursor:pointer;}
.pui-datatable .pui-sortable-column-icon{display:inline-block;margin:-3px 0 -3px 2px;}
.pui-datatable .pui-paginator{border-top:0 none;}
.pui-datatable .pui-datatable-data tr.ui-state-hover{font-weight:inherit;cursor:pointer;}
.pui-datatable tr.ui-state-highlight{cursor:pointer;}
.pui-datatable-scrollable-header,.pui-datatable-scrollable-footer{border:0 none;overflow:hidden;}
.pui-datatable-scrollable-body{overflow:auto;}
.pui-datatable-reflow .pui-datatable-data td .pui-column-title{display:none;}
@media(max-width:35em){.pui-datatable-reflow thead th,.pui-datatable-reflow tfoot td{display:none;}
.pui-datatable-reflow .pui-datatable-data td{text-align:left;display:block;border:0 none;width:100%;-webkit-box-sizing:border-box;-moz-box-sizing:border-box;box-sizing:border-box;float:left;clear:left;}
.pui-datatable-reflow .pui-datatable-data.ui-widget-content{border:0 none;}
.pui-datatable-reflow .pui-datatable-data tr.ui-widget-content{border-left:0 none;border-right:0 none;}
.pui-datatable-reflow .pui-datatable-data td .pui-column-title{padding:.4em;min-width:30%;display:inline-block;margin:-.4em 1em -.4em -.4em;}
}