.pui-galleria{overflow:hidden;visibility:hidden;position:relative;}
.pui-galleria-panel-wrapper{position:relative;padding:0;margin:0;}
.pui-galleria-panel{filter:inherit;position:absolute;top:0;left:0;list-style-type:none;}
.pui-galleria-filmstrip-wrapper{overflow:hidden;margin:5px auto;position:relative;}
.pui-galleria-filmstrip{list-style:none outside none;margin:0;padding:0;width:2340px;z-index:900;position:absolute;top:0;left:0;}
.pui-galleria-frame{float:left;margin-right:5px;opacity:.3;cursor:pointer;}
.pui-galleria-frame-active{opacity:1;}
.pui-galleria-frame-content{overflow:hidden;}
.pui-galleria-nav-next,.pui-galleria-nav-prev{cursor:pointer;position:absolute;}
.pui-galleria-nav-prev{left:5px;}
.pui-galleria-nav-next{right:5px;}
.pui-galleria-caption{position:absolute;left:1px;background-color:rgba(0,0,0,0.5);display:none;color:#FFF;padding:.2em 1em;}
.pui-galleria-panel-content{padding:1em 1.4em;}