.pui-inputtext{margin:0;outline:medium none;padding:4px;font-weight:normal;}
.ui-widget-header .pui-inputtext,.ui-widget-content .pui-inputtext{font-weight:normal;}
.pui-fluid .pui-inputtext{width:100%;}