* html .pui-growl{position:absolute;}
* html .pui-growl-item{padding-bottom:0;}
* html .pui-growl-icon-close{top:7px;right:7px;}
.pui-growl{position:fixed;top:20px;right:20px;width:301px;}
.pui-growl-item-container{position:relative;margin:0 0 10px 0;opacity:.85;filter:alpha(opacity=85);}
.pui-growl-item{display:block;padding:10px 15px;}
.pui-growl-item p{padding:0;margin:0;}
.pui-growl-icon-close{position:absolute;top:5px;right:3px;cursor:pointer;}
.pui-growl-title{font-weight:bold;padding:0 0 7px 0;display:block;}
.pui-growl-image{float:left;margin-left:5px;padding:0;display:block;}
.pui-growl-message{padding:0 0 5px 0;width:220px;float:right;}
.pui-growl-message p{font-weight:normal;}