.pui-progressbar{height:1.2em;text-align:left;position:relative;}
.pui-progressbar .pui-progressbar-value{margin:-1px;height:100%;width:0;position:absolute;display:none;}
.pui-progressbar .pui-progressbar-label{text-align:center;height:100%;width:100%;position:absolute;display:none;font-weight:bold;}