.pui-fieldset,.pui-fieldset .pui-fieldset-legend{padding:.6em 1em;}
.pui-fieldset-toggleable .pui-fieldset-legend{padding:.5em 1em .5em .5em;cursor:pointer;white-space:nowrap;}
.pui-fieldset .pui-fieldset-toggler{padding-right:.1em;margin-top:.1em;float:left;}