.pui-paginator{margin:0;text-align:center;padding:2px;}
.pui-paginator .pui-paginator-top{border-bottom:0 none;}
.pui-paginator .pui-paginator-bottom{border-top:0 none;}
.pui-paginator .pui-paginator-page,.pui-paginator .pui-paginator-pages,.pui-paginator .pui-paginator-next,.pui-paginator .pui-paginator-last,.pui-paginator .pui-paginator-first,.pui-paginator .pui-paginator-prev,.pui-paginator .pui-paginator-current{display:inline-block;padding:2px 6px;zoom:1;margin-left:1px;margin-right:1px;text-decoration:none;outline:none;}
.pui-paginator .pui-paginator-page,.pui-paginator .pui-paginator-next,.pui-paginator .pui-paginator-last,.pui-paginator .pui-paginator-first,.pui-paginator .pui-paginator-prev{cursor:pointer;}
.pui-paginator .pui-paginator-current,.pui-paginator .pui-paginator-rpp-options{margin-left:1em;margin-right:1em;background-image:none;}
.pui-paginator .pui-paginator-next .ui-icon,.pui-paginator .pui-paginator-prev .ui-icon,.pui-paginator .pui-paginator-first .ui-icon,.pui-paginator .pui-paginator-last .ui-icon{height:auto;overflow:inherit;}
.pui-paginator .pui-paginator-jtp-select option,.pui-paginator .pui-paginator-rpp-options option{background-image:none;border:0 none;box-shadow:none;-moz-box-shadow:none;-webkit-box-shadow:none;}