.pui-radiobutton{position:relative;width:16px;margin:2px 0;line-height:16px;cursor:pointer;}
.pui-radiobutton .pui-radiobutton-box{width:16px;height:16px;line-height:16px;-moz-border-radius:10px;-webkit-border-radius:10px;border-radius:10px;}
.pui-radiobutton-icon{font-size:10px;margin-top:3px;margin-left:2px;display:block;}