.pui-shadow{-moz-box-shadow:0 5px 10px rgba(0,0,0,0.8);-webkit-box-shadow:0 5px 10px rgba(0,0,0,0.8);box-shadow:0 5px 10px rgba(0,0,0,0.8);}
.pui-fluid *{box-sizing:border-box;-webkit-box-sizing:border-box;-moz-box-sizing:border-box;}
.ui-widget .ui-icon.fa,.ui-icon.fa{background:none repeat scroll 0 0 transparent!important;text-indent:0!important;}