.pui-button{display:inline-block;position:relative;padding:0;margin-right:.1em;text-decoration:none!important;cursor:pointer;text-align:center;zoom:1;overflow:visible;}
.pui-button-icon-only{width:2.4em;}
.pui-button .pui-button-text{display:block;line-height:normal;}
.pui-button-text-only .pui-button-text{padding:.3em 1em;}
.pui-button-icon-only .pui-button-text{padding:.3em;text-indent:-9999999px;}
.pui-button-text-icon-left .pui-button-text{padding:.3em 1em .3em 2.1em;}
.pui-button-text-icon-right .pui-button-text{padding:.3em 2.1em .3em 1em;}
.pui-button-icon-only .pui-icon,.pui-button-text-icon-left .pui-icon,.pui-button-text-icon-right .pui-icon{position:absolute;top:50%;margin-top:-7px;}
.pui-button-icon-only .pui-icon{left:50%;margin-left:-8px;}
.pui-button-icon-left{left:.5em;}
.pui-button-icon-right{right:.5em;}
.pui-buttonset{margin-right:7px;}
.pui-buttonset .pui-button{margin-left:0;margin-right:0;}
button.pui-button::-moz-focus-inner{border:0;padding:0;}
.pui-fluid .pui-button{width:100%;}
.pui-fluid .ui-buttonset{width:100%;}