
{% extends "layout.html" %}

{% block content %}
<div class="body-content">
    <div class="row">
      <h1>About</h1>
      <p>Brome webserver was created by <a href="http://github.com/brome-hq/">Brome-HQ</a></p>
    </div>
</div>
{% endblock %}

