.pui-menu{width:12.5em;padding:.3em;position:relative;}
.pui-menu.pui-menu-dynamic{position:absolute;display:none;z-index:100000;}
.pui-menu-list{position:static;}
.pui-menu .pui-menu-list .pui-menuitem{border:none;}
.pui-menu .pui-menu-list .ui-widget-header{clear:both;float:left;width:98%;margin:1px 0;}
.pui-menu .pui-menuitem{width:100%;float:left;clear:both;margin:1px 0;padding:0;}
.pui-menu .pui-menuitem-parent{width:100%;float:left;clear:both;margin:1px 0;padding:0;}
.pui-menu .pui-menuitem-link{display:block;width:92%;outline:none;text-decoration:none;font-weight:400;border:solid 1px transparent;float:left;line-height:16px;padding:.3em;cursor:pointer;}
.pui-menu .pui-menuitem-link .pui-menuitem-icon{display:inline-block;float:left;}
.pui-menu .pui-menuitem-text{float:left;}
.pui-menu .ui-widget-header h1,.pui-menu .ui-widget-header h2,.pui-menu .ui-widget-header h3,.pui-menu .ui-widget-header h4,.pui-menu .ui-widget-header h5,.pui-menu .ui-widget-header h6{float:left;display:block;font-size:1em;margin:0 auto;padding:.3em 3%;}
.pui-menu .pui-menu-parent .pui-menu-child{display:none;width:12.5em;padding:.3em;position:absolute;margin:0;outline:0;line-height:1.3;text-decoration:none;font-size:100%;list-style:none;}
.pui-menu .pui-menu-parent{position:relative;}
.pui-menu .pui-menu-parent .pui-submenu-icon{float:right;}
.pui-menubutton{padding:0;}
.pui-menubutton .ui-button{margin:0;}
.pui-menubar{width:auto;}
.pui-menubar .pui-menuitem{width:auto;clear:none;}
.pui-menubar .pui-menu-child .pui-menuitem{width:100%;}
.pui-menubar .pui-menu-child{top:25px;left:0;}
.pui-menubar .pui-menuitem-link{width:auto;padding:.4em .3em;}
.pui-menubar .pui-menu-child .pui-menuitem-link{width:92%;}
.pui-menubar .ui-widget-header{clear:none;width:auto;margin:0 3px 0 0;}
.pui-menubar .ui-widget-header h1,.pui-menubar .ui-widget-header h2,.pui-menubar .ui-widget-header h3,.pui-menubar .ui-widget-header h4,.pui-menubar .ui-widget-header h5,.pui-menubar .ui-widget-header h6{padding:.4em .3em;}
.pui-menubar .pui-menubar-options{float:right;}
.pui-menu .ui-separator{width:98%;height:0;float:left;clear:both;margin:1px 0 0 0;padding:0;border-top:0 none;}
.ui-megamenu td{vertical-align:top;}
.pui-menu.ui-megamenu .pui-menu-parent .pui-menu-child{width:auto;}
.pui-menu.ui-megamenu .pui-menu-child>table{width:auto;}
.pui-menu.ui-megamenu .pui-menu-child .pui-menu-list{width:12.5em;}
.pui-breadcrumb{margin:0;padding:0;overflow:hidden;padding:5px 5px 7px 5px;}
.pui-breadcrumb ul{margin:0;padding:0;display:block;}
.pui-breadcrumb ul li{display:block;float:left;position:relative;overflow:hidden;}
.pui-breadcrumb ul li span{display:block;overflow:hidden;}
.pui-breadcrumb ul li .pui-menuitem-link{display:block;position:relative;overflow:hidden;float:left;margin-top:3px;}
.pui-breadcrumb ul li.fa{padding:0;margin:4px 3px 0 3px;}
.pui-breadcrumb-chevron{float:left;}
.pui-slidemenu .pui-slidemenu-wrapper{position:relative;}
.pui-slidemenu .pui-slidemenu-content{overflow-x:hidden;overflow-y:auto;position:relative;}
.pui-slidemenu .pui-menu-list{position:absolute;top:0;}
.pui-slidemenu .pui-menu-parent{position:static;}
.pui-slidemenu .pui-menu-child{box-shadow:none;border:0 none;background:none repeat scroll 0 0 transparent;}
.pui-slidemenu-backward{position:absolute;bottom:0;width:95%;margin-bottom:.4em;padding:.2em;cursor:pointer;display:none;}
.pui-slidemenu-backward .pui-icon{float:left;margin-top:1px;}
.pui-fluid .pui-menu{width:100%;}