<footer>
  <small>
  <ul class="company">
    <li>© Brome-HQ</li>
  </ul>

    <ul class="footer-nav">

      <li><a href="{{ url_for('public.about') }}">About</a></li>

      <li><a href="mailto:brome.hq@gmail.com">Contact</a></li>
    </ul>
  </small>
</footer>
