.pui-accordion{width:100%;}
.pui-accordion .pui-accordion-header{cursor:pointer;position:relative;margin-top:1px;zoom:1;}
.pui-accordion .pui-accordion-header a{display:block;font-size:1em;padding:.5em .5em .5em 2.2em;}
.pui-accordion .pui-accordion-header .pui-icon{position:absolute;left:.5em;top:50%;margin-top:-8px;}
.pui-accordion .pui-accordion-content{padding:1em 2.2em;border-top:0;margin-top:-2px;position:relative;top:1px;margin-bottom:2px;overflow:auto;zoom:1;}
.pui-accordion .pui-accordion-header.ui-state-disabled,.pui-accordion .pui-accordion-header.ui-state-disabled a{cursor:default;}