.pui-spinner{display:inline-block;overflow:visible;padding:0;position:relative;vertical-align:middle;}
.pui-spinner-input{vertical-align:middle;text-align:right;padding-right:20px;}
.pui-spinner-button{cursor:default;display:block;font-size:.5em;height:50%;margin:0;overflow:hidden;padding:0;position:absolute;right:0;text-align:center;vertical-align:middle;width:16px;z-index:100;}
.pui-spinner .pui-icon{left:0;margin-top:-8px;position:absolute;top:50%;}
.pui-spinner-up{top:0;}
.pui-spinner-down{bottom:0;}