
{% extends "layout.html" %}
{% block content %}
<!-- Main jumbotron for a primary marketing message or call to action -->
<div class="jumbotron">

  <h1>Welcome to the Brome webserver</h1>

  <p><a href="http://brome.readthedocs.org/en/" class="btn btn-primary btn-large">Learn more &raquo;</a></p>
</div><!-- /.jumbotron -->

<div class="body-content">
  <div class="row">
    <div class="col-lg-3">
      <h2><i class="fa fa-cloud"></i> Run your test on Amazon EC2, Virtualbox or on your local machine</h2>
      <p><a class="btn btn-default" href="{{ url_for('testbatch.launch') }}">Launch a new test batch</a></p>
    </div>
    <div class="col-lg-3">
      <h2><i class="fa fa-wrench"></i> Brome is easily configurable</h2>
      <p><a class="btn btn-default" href="{{ url_for('admin.configuration') }}">Go to the brome configuration</a></p>
    </div>
    <div class="col-lg-3">
      <h2><i class="fa fa-book"></i> Brome has a lot of documentation</h2>
      <p><a class="btn btn-default" href="http://brome.readthedocs.org/en/" target="_blank">See official documentation</a></p>
    </div>
    <div class="col-lg-3">
      <h2><i class="fa fa-file"></i> Brome create report for each test batch</h2>
      <p><a class="btn btn-default" href="{{ url_for('testbatch.list') }}">Go to the Test batch list</a></p>
   </div>
  </div><!-- /.row -->
</div>
{% endblock %}

