
<!doctype html>
<!-- paulirish.com/2008/conditional-stylesheets-vs-css-hacks-answer-neither/ -->
<!--[if lt IE 7]> <html class="no-js lt-ie9 lt-ie8 lt-ie7" lang="en"> <![endif]-->
<!--[if IE 7]>    <html class="no-js lt-ie9 lt-ie8" lang="en"> <![endif]-->
<!--[if IE 8]>    <html class="no-js lt-ie9" lang="en"> <![endif]-->
<!--[if gt IE 8]><!--> <html class="no-js" lang="en"> <!--<![endif]-->
<head>
  <meta charset="utf-8">

  <link rel="brome icon" href="{{ url_for('static', filename='brome.ico') }}">

  <title>{% block page_title %}
  
    webserver
  
    {% endblock %}
  </title>
  <meta name="description" content="{% block meta_description %}{% endblock %}">
  <meta name="author" content="{% block meta_author %}{% endblock %}">

  <!-- Mobile viewport optimized: h5bp.com/viewport -->
  <meta name="viewport" content="width=device-width">

  <link rel="stylesheet" href="{{ url_for('static', filename='libs/font-awesome4/css/font-awesome.min.css') }}">
  {% assets "css_all" %}
    <link rel="stylesheet" href="{{ ASSET_URL }}">
  {% endassets %}

    <!-- JavaScript -->
     <script type="text/javascript" src="/static/libs/sijax/sijax.js"></script>
     <script type="text/javascript">
         {{ g.sijax.get_js()|safe }}
     </script>
    {% assets "js_all" %}
        <script type="text/javascript" src="{{ ASSET_URL }}"></script>
    {% endassets %}

     <script type="text/javascript">
        $(function() {
            onTestBatchDelete = function (testbatch_id) {
                BootstrapDialog.show({
                    title: 'Delete Test Batch',
                    message: 'Are you sure you want to delete this test batch?',
                    buttons: [{
                        label: 'No',
                        action: function(me) {
                            me.close();
                        }
                    }, {
                        label: 'Yes',
                        cssClass: 'btn btn-danger',
                        action: function(me) {
                            me.close();
                            Sijax.request('delete_test_batch', [testbatch_id]);
                        }
                    }]
                });
            }

            onTestBatchStop = function (testbatch_id) {
                BootstrapDialog.show({
                    title: 'Stop Test Batch',
                    message: 'Are you sure you want to stop this test batch?',
                    buttons: [{
                        label: 'No',
                        action: function(me) {
                            me.close();
                        }
                    }, {
                        label: 'Yes',
                        cssClass: 'btn btn-danger',
                        action: function(me) {
                            me.close();
                            Sijax.request('stop_test_batch', [testbatch_id]);
                        }
                    }]
                });
            }
        });
     </script>

    {% block js %}{% endblock %}
    <!-- end scripts -->
  {% block css %}{% endblock %}

</head>
<body class="{% block body_class %}{% endblock %}">
{% block body %}
{% with form=form  %}
{% include "nav.html" %}
{% endwith %}

<header>{% block header %}{% endblock %}</header>
<div class="{% block content_class %}container{% endblock content_class %}">

  <div role="main">
    {% with messages = get_flashed_messages(with_categories=true) %}
    {% if messages %}
    <div class="row">
      <div class="col-md-12">
        {% for category, message in messages %}
        <div class="alert alert-{{ category }}">
          <a class="close" title="Close" href="#" data-dismiss="alert">&times;</a>
         {{message}}
        </div><!-- end .alert -->
        {% endfor %}
      </div><!-- end col-md -->
    </div><!-- end row -->
        {% endif %}
    {% endwith %}

    {% block content %}{% endblock %}
  </div>

  <!--modal dialog -->
    <div class="modal fade">
        <div class="modal-dialog">
            <div class="modal-content">
                <div class="modal-header">
                    <button type="button" class="close" data-dismiss="modal" aria-hidden="true">×</button>
                    <h4 class="modal-title">Modal title</h4>
                </div>
                <div class="modal-body">
                    <p>One fine body…</p>
                </div>
                <div class="modal-footer">
                    <button type="button" class="btn btn-default" data-dismiss="modal">Close</button>
                    <button type="button" class="btn btn-primary">Save changes</button>
                </div>
            </div><!-- /.modal-content -->
        </div><!-- /.modal-dialog -->
    </div><!-- /.modal -->

</div><!-- end container -->

{% include "footer.html" %}

{% endblock %}
</body>
</html>

