
{% extends "layout.html" %}

{% block page_title %}Server error{% endblock %}

{% block content %}
<div class="jumbotron">
    <div class="text-center">
        <h1>500</h1>
        <p>Sorry, something went wrong on our system. Don't panic, we are fixing it! Please try again later.</p>
    </div>
</div>
{% endblock %}

