
<nav class="navbar navbar-inverse navbar-fixed-top" role="navigation">
  <div class="container">

  <!-- Brand and toggle get grouped for better mobile display -->
  <div class="navbar-header">
    <button type="button" class="navbar-toggle" data-toggle="collapse" data-target=".navbar-ex1-collapse">
      <span class="sr-only">Toggle navigation</span>
      <span class="icon-bar"></span>
      <span class="icon-bar"></span>
      <span class="icon-bar"></span>
    </button>
    <a class="navbar-brand" href="{{ url_for('public.home') }}">

      Home

    </a>
  </div>
  <!-- Collect the nav links, forms, and other content for toggling -->
  <div class="collapse navbar-collapse navbar-ex1-collapse">
    <ul class="nav navbar-nav">
        {% if current_user and current_user.is_authenticated() %}
          <li><a href="{{ url_for('admin.configuration') }}">Configuration</a></li>
          <li><a href="{{ url_for('testbatch.launch') }}">Launch Test Batch</a></li>
          <li><a href="{{ url_for('testbatch.list') }}">Test Batch</a></li>
        {% endif %}
    </ul>
    {% if current_user and current_user.is_authenticated() %}
    <ul class="nav navbar-nav navbar-right">
        <li>
            <p class="navbar-text">Logged in as {{ current_user.username }}</p>
        </li>
        <li><a class="navbar-link" href="{{ url_for('public.logout') }}"><i class="fa fa-sign-out"></i></a></li>

    </ul>
    {% elif form %}
    <ul class="nav navbar-nav navbar-right">
      <li><a href="{{ url_for('public.register') }}">Create account</a></li>
    </ul>
    <form id="loginForm" method="POST" class="navbar-form form-inline navbar-right" action="/" role="login">
      {{ form.hidden_tag() }}
      <div class="form-group">
        {{ form.username(placeholder="Username", class_="form-control") }}
        {{ form.password(placeholder="Password", class_="form-control") }}
      </div>
      <button type="submit" class="btn btn-default">Log in</button>
    </form>
    {% endif %}
  </div><!-- /.navbar-collapse -->
  </div><!-- /.container -->
</nav>

