.pui-picklist .pui-picklist-listwrapper{float:left;width:150px;}
.pui-picklist .pui-picklist-list{list-style-type:none;margin:0;padding:0;overflow:auto;height:200px;}
.pui-picklist .pui-picklist-buttons{float:left;margin:48px 10px 0 10px;padding:0;}
.pui-picklist .pui-picklist-list li{margin:1px;padding:2px;}
.pui-picklist .pui-button{display:block;margin-bottom:.3em;}
.pui-picklist .pui-picklist-item{cursor:pointer;border:0 none;font-weight:inherit;}
.pui-picklist .pui-picklist-caption{text-align:center;padding:4px 10px 4px 10px;border-bottom:0 none;}
.pui-picklist table{width:100%;border-collapse:collapse;}
.pui-picklist .pui-picklist-filter{padding-right:15px;width:86%;}
.pui-picklist .pui-picklist-filter-container{position:relative;margin:0;padding:0;}
.pui-picklist .pui-picklist-filter-container .pui-icon{position:absolute;top:5px;right:2px;}