.pui-grid{clear:both;padding:0;margin:0;}
.pui-grid:before,.pui-grid:after{content:"";display:table;}
.pui-grid:after{clear:both;}
.pui-grid .pui-grid-row{display:-webkit-box;display:-moz-box;display:-ms-flexbox;display:-webkit-flex;display:flex;clear:both;}
.pui-grid-row:after{clear:both;content:"";display:table;}
.pui-grid-col-1,.pui-grid-col-2,.pui-grid-col-3,.pui-grid-col-4,.pui-grid-col-5,.pui-grid-col-6,.pui-grid-col-7,.pui-grid-col-8,.pui-grid-col-9,.pui-grid-col-10,.pui-grid-col-11,.pui-grid-col-12{float:left;box-sizing:border-box;}
.pui-grid-col-1{width:8.33333%;}
.pui-grid-col-2{width:16.66666%;}
.pui-grid-col-3{width:25%;}
.pui-grid-col-4{width:33.33333%;}
.pui-grid-col-5{width:41.66666%;}
.pui-grid-col-6{width:50%;}
.pui-grid-col-7{width:58.33333%;}
.pui-grid-col-8{width:66.66666%;}
.pui-grid-col-9{width:75%;}
.pui-grid-col-10{width:83.33333%;}
.pui-grid-col-11{width:91.66666%;}
.pui-grid-col-12{width:100%;}
@media(min-width:480px){.pui-grid-fixed{width:480px;}
}
@media(min-width:768px){.pui-grid-fixed{width:768px;}
}
@media(min-width:960px){.pui-grid-fixed{width:960px;}
}
@media(min-width:1024px){.pui-grid-fixed{width:1024px;}
}
@media(max-width:35em){.pui-grid-responsive .pui-grid-row{display:block;}
.pui-grid-responsive .pui-grid-col-1,.pui-grid-responsive .pui-grid-col-2,.pui-grid-responsive .pui-grid-col-3,.pui-grid-responsive .pui-grid-col-4,.pui-grid-responsive .pui-grid-col-5,.pui-grid-responsive .pui-grid-col-6,.pui-grid-responsive .pui-grid-col-7,.pui-grid-responsive .pui-grid-col-8,.pui-grid-responsive .pui-grid-col-9,.pui-grid-responsive .pui-grid-col-10,.pui-grid-responsive .pui-grid-col-11,.pui-grid-responsive .pui-grid-col-12{width:100%;float:none;}
}