.pui-password-panel{padding:4px 10px;width:150px;margin-top:2px;}
.pui-password-panel .pui-password-meter{height:10px;background:transparent url("password-meter.png") no-repeat left top;padding:0;margin:0;}
.pui-password-info{margin-top:4px;}
.pui-password-panel-overlay{position:absolute;}